@@ -81,9 +81,12 @@ class Piece(ABC):
         for move in self.move_pattern():
             try:
                 new_move = Move.from_position(self.position, move)
+
                 if board and new_move:
-                    new_move = BoardMove(board, new_move.text).process()
-                if new_move:
+                    result = BoardMove(board, new_move.text).process()
+                    if result:
+                        allowed_moves.append(new_move)
+                elif new_move:
                     allowed_moves.append(new_move)
             except IndexError:
                 pass
